==> iRRAM_2004_01.tar.gz: iRRAM_2004_01/obj/GMP/gmp_extension.cc <==
/*

gmp_extension.cc -- extension to the GMP float functions for the iRRAM library
 
Copyright (C) 2002/2003 Norbert Mueller
 
This file is part of the iRRAM Library.
 
The iRRAM Library is free software; you can redistribute it and/or modify
it under the terms of the GNU Library General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at your
option) any later version.
 
The iRRAM Library is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
License for more details.
 
You should have received a copy of the GNU Library General Public License
along with the iRRAM Library; see the file COPYING.LIB.  If not, write to
the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
MA 02111-1307, USA. 
*/

#include "iRRAM_core.h"
#include "gmp_extension.h"

DYADIC glob_arg;
DYADIC glob_res;

inline void mp_ext_start(mpf_ptr r, mpf_srcptr u,long p,long proc(long)){
  mpf_set_prec(glob_arg.value,mpf_get_prec(u));
  mpf_set(glob_arg.value,u);
  iRRAM_exec(proc,p);
  mpf_set_prec(r,mpf_get_prec(glob_res.value));
  mpf_set(r,glob_res.value);
}

long compute_test(long p)
   { glob_res=approx(REAL(glob_arg),p); }
void mpf_ext_test (mpf_ptr r, mpf_srcptr u, long p)
   { mp_ext_start(r,u,p,compute_test); }

long compute_exp(long p)
   { glob_res=approx(exp(REAL(glob_arg)),p); }
void mpf_ext_exp (mpf_ptr r, mpf_srcptr u, long p)
   { mp_ext_start(r,u,p,compute_exp); }  

long compute_log(long p)
   { glob_res=approx(log(REAL(glob_arg)),p); }
void mpf_ext_log (mpf_ptr r, mpf_srcptr u, long p)
   { mp_ext_start(r,u,p,compute_log); }  

long compute_sin(long p)
   { glob_res=approx(sin(REAL(glob_arg)),p); }
void mpf_ext_sin (mpf_ptr r, mpf_srcptr u, long p)
   { mp_ext_start(r,u,p,compute_sin); }  

long compute_cos(long p)
   { glob_res=approx(cos(REAL(glob_arg)),p); }
void mpf_ext_cos (mpf_ptr r, mpf_srcptr u, long p)
   { mp_ext_start(r,u,p,compute_cos); }  

long compute_tan(long p)
   { glob_res=approx(tan(REAL(glob_arg)),p); }
void mpf_ext_tan (mpf_ptr r, mpf_srcptr u, long p)
   { mp_ext_start(r,u,p,compute_tan); }

==> iRRAM_2005_03.tar.gz: iRRAM_2005_03/obj/GMP/gmp_extension.cc <==
/*

gmp_extension.cc -- extension to the GMP float functions for the iRRAM library
 
Copyright (C) 2002/2003 Norbert Mueller
 
This file is part of the iRRAM Library.
 
The iRRAM Library is free software; you can redistribute it and/or modify
it under the terms of the GNU Library General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at your
option) any later version.
 
The iRRAM Library is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
License for more details.
 
You should have received a copy of the GNU Library General Public License
along with the iRRAM Library; see the file COPYING.LIB.  If not, write to
the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
MA 02111-1307, USA. 
*/

#include "iRRAM_core.h"
#include "gmp_extension.h"

DYADIC glob_arg;
DYADIC glob_res;

inline void mp_ext_start(mpf_ptr r, mpf_srcptr u,int p,int proc(int)){
  mpf_set_prec(glob_arg.value,mpf_get_prec(u));
  mpf_set(glob_arg.value,u);
  iRRAM_exec(proc,p);
  mpf_set_prec(r,mpf_get_prec(glob_res.value));
  mpf_set(r,glob_res.value);
}

int compute_exp(int p)
   { glob_res=approx(exp(REAL(glob_arg)),p); }
void mpf_ext_exp (mpf_ptr r, mpf_srcptr u, int p)
   { mp_ext_start(r,u,p,compute_exp); }  

int compute_log(int p)
   { glob_res=approx(log(REAL(glob_arg)),p); }
void mpf_ext_log (mpf_ptr r, mpf_srcptr u, int p)
   { mp_ext_start(r,u,p,compute_log); }  

int compute_sin(int p)
   { glob_res=approx(sin(REAL(glob_arg)),p); }
void mpf_ext_sin (mpf_ptr r, mpf_srcptr u, int p)
   { mp_ext_start(r,u,p,compute_sin); }  

int compute_cos(int p)
   { glob_res=approx(cos(REAL(glob_arg)),p); }
void mpf_ext_cos (mpf_ptr r, mpf_srcptr u, int p)
   { mp_ext_start(r,u,p,compute_cos); }  

int compute_tan(int p)
   { glob_res=approx(tan(REAL(glob_arg)),p); }
void mpf_ext_tan (mpf_ptr r, mpf_srcptr u, int p)
   { mp_ext_start(r,u,p,compute_tan); }
